#
# spec file for package python-pip
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# NOTE(saschpe): git invocation and pythonpath issues with testrepository
# enable testing with a build conditional (off by default):
%bcond_with test
Name:           python-pip
Version:        19.0.2
Release:        0
Summary:        A Python package management system
License:        MIT
Group:          Development/Languages/Python
URL:            http://www.pip-installer.org
Source:         https://files.pythonhosted.org/packages/source/p/pip/pip-%{version}.tar.gz
Patch0:         pip-shipped-requests-cabundle.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       ca-certificates
Requires:       coreutils
Requires:       python-setuptools
Requires:       python-xml
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     ca-certificates-mozilla
BuildArch:      noarch
%if %{with test}
# Test requirements:
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pretend}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scripttest >= 1.3}
BuildRequires:  %{python_module virtualenv >= 1.10}
%endif
%python_subpackages

%description
Pip is a replacement for easy_install. It uses mostly the same techniques for
finding packages, so packages that were made easy_installable should be
pip-installable as well.

%prep
%setup -q -n pip-%{version}
%patch0 -p1
# remove shebangs verbosely (if only sed would offer a verbose mode...)
for f in $(find src -name \*.py -exec grep -l '^#!/usr/bin/env' {} \;); do
    sed -i 's|^#!/usr/bin/env .*$||g' $f
done
rm src/pip/_vendor/certifi/cacert.pem

%build
%python_build

%install
%python_install
%prepare_alternative pip
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%python_expand py.test-%{$python_version}
%endif

%pre
# Since /usr/bin/pip became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternatives-ified package:
[ -h %{_bindir}/pip ] || rm -f %{_bindir}/pip

%post
# can't use `python_install_alternative` because it's pipX.Y, not pip-X.Y
PRIO=$(echo %{python_version} | tr -d .)
%ifpypy3
%install_alternative pip %{_bindir}/pip-%{pypy3_bin_suffix} $PRIO
%else
%install_alternative pip %{_bindir}/pip%{python_version} $PRIO
%endif

%postun
%ifpypy3
%uninstall_alternative pip %{_bindir}/pip-%{pypy3_bin_suffix}
%else
%uninstall_alternative pip %{_bindir}/pip%{python_version}
%endif

%files %{python_files}
%license LICENSE.txt
%doc AUTHORS.txt NEWS.rst README.rst
%{_bindir}/pip
%python2_only %{_bindir}/pip2
%python3_only %{_bindir}/pip3
%ifpypy3
%{_bindir}/pip-%{pypy3_bin_suffix}
%else
%{_bindir}/pip%{python_version}
%endif
%ghost %{_sysconfdir}/alternatives/pip
%{python_sitelib}/pip-%{version}-py%{python_version}.egg-info
%{python_sitelib}/pip

%changelog
